==> flyway-core-10.17.2-sources.jar: org/flywaydb/core/internal/publishing/PublishingConfigurationExtension.java <==
/*-
 * ========================LICENSE_START=================================
 * flyway-core
 * ========================================================================
 * Copyright (C) 2010 - 2024 Red Gate Software Ltd
 * ========================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */
package org.flywaydb.core.internal.publishing;

import lombok.Getter;
import lombok.Setter;
import org.flywaydb.core.extensibility.ConfigurationExtension;

@Getter
@Setter
public class PublishingConfigurationExtension implements ConfigurationExtension {
    private static final String FLYWAY_PUBLISH_RESULT = "flyway.publishResult";
    private boolean publishResult = false;

    @Override
    public String getNamespace() {
        return "";
    }

    @Override
    public String getConfigurationParameterFromEnvironmentVariable(final String environmentVariable) {
        if ("FLYWAY_PUBLISH_RESULT".equals(environmentVariable)) {
            return FLYWAY_PUBLISH_RESULT;
        }
        return null;
    }
}

==> flyway-core-10.20.1-sources.jar: org/flywaydb/core/internal/publishing/PublishingConfigurationExtension.java <==
/*-
 * ========================LICENSE_START=================================
 * flyway-core
 * ========================================================================
 * Copyright (C) 2010 - 2024 Red Gate Software Ltd
 * ========================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */
package org.flywaydb.core.internal.publishing;

import lombok.Getter;
import lombok.Setter;
import org.flywaydb.core.extensibility.ConfigurationExtension;

@Getter
@Setter
public class PublishingConfigurationExtension implements ConfigurationExtension {
    private static final String FLYWAY_PUBLISH_RESULT = "flyway.publishResult";
    private static final String FLYWAY_CHECK_DRIFT_ON_MIGRATE = "flyway.checkDriftOnMigrate";
    private boolean publishResult = false;
    private boolean checkDriftOnMigrate = false;

    @Override
    public String getNamespace() {
        return "";
    }

    @Override
    public String getConfigurationParameterFromEnvironmentVariable(final String environmentVariable) {
        if ("FLYWAY_PUBLISH_RESULT".equals(environmentVariable)) {
            return FLYWAY_PUBLISH_RESULT;
        }
        if ("FLYWAY_CHECK_DRIFT_ON_MIGRATE".equals(environmentVariable)) {
            return FLYWAY_CHECK_DRIFT_ON_MIGRATE;
        }
        return null;
    }
}
